Name:           nemo
Summary:        File manager for Cinnamon
Version:        3.2.2
Release:        4%{?dist}
License:        GPLv2+ and LGPLv2+
URL:            https://github.com/linuxmint/nemo
Source0:        https://github.com/linuxmint/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/linuxmint/mint-common/master/usr/share/nemo/actions/mint-artwork-cinnamon-thunderbird.nemo_action
Source2:        nemo-fedora.gschema.override
Patch0:         configure.patch

Requires:       redhat-menus
Requires:       gvfs%{_isa}
Requires:       gnome-icon-theme
# required for for gtk-stock fallback
Requires:       gnome-icon-theme-legacy
Requires:       cinnamon-translations

BuildRequires:  gnome-common
BuildRequires:  intltool
BuildRequires:  rarian-compat
BuildRequires:  python3-polib
BuildRequires:  python3-gobject-base
BuildRequires:  desktop-file-utils
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(cinnamon-desktop) >= 3.2.0
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(libexif)
BuildRequires:  pkgconfig(exempi-2.0)
BuildRequires:  pkgconfig(libselinux)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
BuildRequires:  pkgconfig(libnotify)

# the main binary links against libnemo-extension.so
# don't depend on soname, rather on exact version
Requires:       nemo-extensions%{?_isa} = %{version}-%{release}

%description
Nemo is the file manager and graphical shell for the Cinnamon desktop
that makes it easy to manage your files and the rest of your system.
It allows to browse directories on local and remote filesystems, preview
files and launch applications associated with them.
It is also responsible for handling the icons on the Cinnamon desktop.

%package extensions
Summary: Nemo extensions library
License: LGPLv2+
Requires:   %{name}%{?_isa} = %{version}-%{release}

%description extensions
This package provides the libraries used by nemo extensions.

%package devel
Summary: Support for developing nemo extensions
License: LGPLv2+
Requires:   %{name}%{?_isa} = %{version}-%{release}


%description devel
This package provides libraries and header files needed
for developing nemo extensions.

%prep
%autosetup -p1 -n %{name}-%{?commit0}%{?!commit0:%{version}}
NOCONFIGURE=1 ./autogen.sh

%build
%configure --disable-static \
           --disable-update-mimedb \
           --disable-schemas-compile \
           --enable-tracker=no

sed -i -e 's/ -shared / -Wl,-O1,--as-needed\0 /g' libtool

%make_build V=1

%install
%make_install

install -D -m 0644 %{SOURCE2} $RPM_BUILD_ROOT/%{_datadir}/glib-2.0/schemas/nemo-fedora.gschema.override

install -D -m 0644 %{SOURCE1} $RPM_BUILD_ROOT/%{_datadir}/nemo/actions/fedora-cinnamon-thunderbird.nemo_action

desktop-file-install --delete-original \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications \
  --add-only-show-in X-Cinnamon \
  $RPM_BUILD_ROOT%{_datadir}/applications/*

# create extensions directoy
mkdir -p $RPM_BUILD_ROOT%{_libdir}/nemo/extensions-3.0/

#Remove libtool archives.
find $RPM_BUILD_ROOT -name '*.la' -or -name '*.a' | xargs rm -f

#Remove icon-theme.cache
rm -f $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/icon-theme.cache
rm -f $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/.icon-theme.cache

%post
  /usr/bin/update-desktop-database &> /dev/null || :
  /bin/touch --no-create %{_datadir}/mime/packages &>/dev/null || :
  /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
  /usr/bin/update-mime-database %{_datadir}/mime &> /dev/null || :
  /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
  /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
  /usr/bin/update-desktop-database &> /dev/null || :
  /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :
fi

%posttrans
  /usr/bin/update-mime-database %{?fedora:-n} %{_datadir}/mime &> /dev/null || :
  /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
  /usr/bin/glib-compile-schemas %{_datadir}/glib-2.0/schemas &> /dev/null || :

%post extensions -p /sbin/ldconfig

%postun extensions -p /sbin/ldconfig

%files
%doc AUTHORS NEWS
%license COPYING COPYING-DOCS
%{_datadir}/nemo/
%{_datadir}/applications/*
%{_datadir}/mime/packages/nemo.xml
%{_bindir}/*
%{_datadir}/icons/hicolor/*/apps/nemo.png
%{_datadir}/icons/hicolor/*/actions/nemo-eject.png
%{_datadir}/icons/hicolor/scalable/*/*.svg
%{_datadir}/icons/hicolor/48x48/status/progress-*.png
%{_datadir}/dbus-1/services/org.Nemo.service
%{_datadir}/dbus-1/services/org.nemo.freedesktop.FileManager1.service
%{_mandir}/man1/nemo-connect-server.1.*
%{_mandir}/man1/nemo.1.*
%{_libexecdir}/nemo-convert-metadata
%{_libexecdir}/nemo-extensions-list
%{_datadir}/glib-2.0/schemas/*
%dir %{_libdir}/nemo/
%dir %{_libdir}/nemo/extensions-3.0/
%{_datadir}/polkit-1/actions/org.nemo.root.policy
%{_datadir}/gtksourceview-?.0/language-specs/nemo_action.lang

%files extensions
%license COPYING.EXTENSIONS COPYING.LIB
%{_libdir}/libnemo-extension.so.*
%dir %{_libdir}/nemo/
%{_libdir}/girepository-1.0/Nemo-3.0.typelib

%files devel
%{_includedir}/nemo/
%{_libdir}/pkgconfig/*
%{_libdir}/*.so
%{_datadir}/gir-1.0/*.gir

%changelog
* Wed Feb 01 2017 Björn Esser <besser82@fedoraproject.org> - 3.2.2-4
- Use Noto Sans font on Fedora 24+, too

* Sun Jan 29 2017 Leigh Scott <leigh123linux@googlemail.com> - 3.2.2-3
- Clean up

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 3.2.2-2
- Rebuild for Python 3.6

* Mon Dec 12 2016 leigh scott <leigh123linux@googlemail.com> - 3.2.2-1
- update to 3.2.2 release

* Sat Dec 10 2016 leigh scott <leigh123linux@googlemail.com> - 3.2.1-1
- update to 3.2.1 release

* Tue Nov 22 2016 leigh scott <leigh123linux@googlemail.com> - 3.2.0-2
- add 'send by email' action for thunderbird

* Mon Nov 07 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.2.0-1
- update to 3.2.0 release

* Fri Oct 28 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.7-2.git6e2dcd3
- update to latest git snapshot

* Mon Oct 24 2016 leigh scott <leigh123linux@googlemail.com> - 3.0.7-1.git6c2a9ca
- update to git snapshot

* Tue Oct 11 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.6-6
- rebuilt

* Sun Jul 24 2016 leigh scott <leigh123linux@googlemail.com> - 3.0.6-5
- rebuilt yet again (gtk-3.21.3 desktop window redraw issue)

* Sun Jul 24 2016 leigh scott <leigh123linux@googlemail.com> - 3.0.6-4
- rebuilt

* Sat Jul 23 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.6-3
- fix gtk-3.21.3 desktop window redraw issue

* Sun Jul 10 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.6-2
- remove unwanted build flags

* Fri Jun 24 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.6-1
- update to 3.0.6 release

* Fri Jun 17 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.5-3
- change source tag
- fix log spam

* Sun Jun 05 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.5-2
- fix scrolled window issue (raveit65)

* Tue May 31 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.5-1
- update to 3.0.5 release

* Thu May 26 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.3-2
- fix desktop font highlighting when renaming (raveit65)

* Tue May 24 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.3-1
- update to 3.0.3 release

* Fri May 20 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.2-1
- update to 3.0.2 release

* Wed May 11 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.1-1
- update to 3.0.1 release

* Sun Apr 24 2016 Leigh Scott <leigh123linux@googlemail.com> - 3.0.0-1
- update to 3.0.0 release

* Sat Mar 26 2016 Leigh Scott <leigh123linux@googlemail.com> - 2.8.7-3
- fix another gtk-3.19 issue

* Fri Mar 25 2016 Leigh Scott <leigh123linux@googlemail.com> - 2.8.7-2
- fix gtk-3.19 issue

* Wed Mar 09 2016 Leigh Scott <leigh123linux@googlemail.com> - 2.8.7-1
- update to 2.8.7 release

* Thu Feb 18 2016 Leigh Scott <leigh123linux@googlemail.com> - 2.8.6-4
- add another style class patch (raveit65)
- add only show in cinnamon for desktop files

* Sun Feb 14 2016 Leigh Scott <leigh123linux@googlemail.com> - 2.8.6-3
- fix gcc-6.0 compile error
- add style classes patch (raveit65)

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.8.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Dec 29 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.8.6-1
- update to 2.8.6 release
- patch to fix bz 1287917 & 1288324

* Sat Nov 21 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.8.5-1
- update to 2.8.5 release

* Mon Nov 09 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.8.2-2
- rebuilt

* Mon Nov 09 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.8.2-1
- update to 2.8.2 release
 
* Mon Oct 26 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.8.1-1
- update to 2.8.1 release

* Thu Oct 22 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.8.0-1
- update to 2.8.0 release

* Tue Sep 01 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.6.7-2
- fix deprecation warning

* Sun Jun 28 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.6.7-1
- update to 2.6.7 release
- clean up scriptlets

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.6.6-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Jun 15 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.6.6-1
- update to 2.6.6 release
- drop adwaita sub-package

* Thu Jun 11 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.6.5-2
- fix extension list for 64bit
- add patch for preferences

* Wed May 27 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.6.5-1
- update to 2.6.5 release

* Mon May 25 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.6.4-1
- update to 2.6.4 release

* Thu May 21 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.6.3-1
- update to 2.6.3 release

* Thu May 21 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.6.2-1
- update to 2.6.2 release

* Wed May 20 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.6.1-1
- update to 2.6.1 release

* Wed May 20 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.6.0-1
- update to 2.6.0 release

* Sat May 16 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.5.0-0.2.gita06e815
- update to git snapshot

* Tue May 05 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.5.0-0.1.git1afb0a3
- update to git snapshot

* Thu Apr 02 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.4.5-2
- drop merged patch

* Thu Apr 02 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.4.5-1
- update to 2.4.5

* Sun Jan 18 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.4.4-4
- f20 also needs a adwaita fix

* Sun Jan 18 2015 Leigh Scott <leigh123linux@googlemail.com> - 2.4.4-3
- add patch to fix statusbar size

* Sun Dec 21 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.4.4-2
- add patch to fix nemo desktop font colour
- raise thunbnail file size limit

* Wed Nov 26 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.4.4-1
- update to 2.4.4

* Sun Nov 23 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.4.3-1
- update to 2.4.3

* Wed Nov 12 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.4.2-1
- update to 2.4.2

* Fri Oct 31 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.4.0-1
- update to 2.4.0

* Tue Oct 28 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.4.0-0.3.gitb157906
- update to latest git

* Fri Oct 10 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.4.0-0.2.git88705b5
- update to latest git

* Tue Sep 30 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.4.0-0.1.git676b171
- update to latest git

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Wed Aug 13 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.2.4-1
- update to 2.2.4
- drop upstream patch

* Tue Aug 12 2014 Rex Dieter <rdieter@fedoraproject.org> 2.2.3-3
- update mime scriptlet

* Tue Jul 22 2014 Kalev Lember <kalevlember@gmail.com> - 2.2.3-2
- Rebuilt for gobject-introspection 1.41.4

* Fri Jun 27 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.2.3-1
- update to 2.2.3

* Tue Jun 17 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.2.2-4
- Fix bookmark crash when umount

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.2.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 30 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.2.2-2
- add requires gnome-icon-theme-legacy

* Wed May 21 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.2.2-1
- update to 2.2.2

* Fri May 02 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.2.1-1
- update to 2.2.1

* Sat Apr 12 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.2.0-1
- update to 2.2.0

* Mon Mar 03 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.0.8-9
- remove tracker support (bz 1071601) so search works
- fix adwaita-nemo theme issue (bz 1066547)

* Thu Feb 20 2014 Adam Williamson <awilliam@redhat.com> - 2.0.8-8
- rebuild against updated tracker

* Fri Jan 24 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.0.8-7
- fix adwaita theme issue

* Thu Jan 02 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.0.8-6
- patch to make background transparent

* Thu Jan 02 2014 Leigh Scott <leigh123linux@googlemail.com> - 2.0.8-5
- hopefully fix rename position issue (bz 1045181)

* Mon Dec 23 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.8-4
- add patch to build against tracker-1.8

* Mon Dec 23 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.8-3
- change tracker build requires

* Sun Dec 22 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.8-2
- add git rollup patch (bz 1045181)

* Mon Dec 02 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.8-1
- update to 2.0.8

* Sun Nov 24 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.7-1
- update to 2.0.7

* Sun Nov 03 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.5-1
- update to 2.0.5

* Thu Oct 31 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.4-1
- update to 2.0.4
- add obsoletes nemo-open-terminal

* Wed Oct 30 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.3-1
- update to 2.0.3

* Thu Oct 24 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.2-1
- update to 2.0.2

* Sun Oct 20 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.1-2
- add obsoletes nemo-seahorse

* Fri Oct 18 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.1-1
- update to 2.0.1

* Wed Oct 09 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.0-2
- rebuilt with tracker support

* Wed Oct 02 2013 Leigh Scott <leigh123linux@googlemail.com> - 2.0.0-1
- update to 2.0.0

* Tue Oct 01 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.9.1-2
- set some defaults

* Mon Sep 30 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.9.1-1
- update to 1.9.1

* Thu Sep 26 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.6-0.8.git60e40aa
- update to latest git

* Thu Sep 19 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.6-0.7.git1c25115
- update to latest git

* Thu Sep 19 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.6-0.6.git07ae0a8
- update to latest git

* Wed Sep 18 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.6-0.5.gitea09d20
- update to latest git

* Sun Aug 25 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.6-0.4.gitfccc703
- update to latest git
- Change buildrequires to cinnamon-desktop-devel
- Change requires to cinnamon-desktop

* Sat Aug 24 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.6-0.3.git9d08c6c
- add requires cinnamon-translations

* Sat Aug 24 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.6-0.2.git9d08c6c
- update to latest git

* Sat Aug 24 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.6-0.1.gitb2776a2
- update to latest git
- adjust for new cinnamon-translations package

* Thu Aug 22 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.5-3
- rebuilt

* Wed Aug 21 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.5-2
- supress gtk DEPRECATED

* Wed Aug 21 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.5-1
- Update to version 1.8.5

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.8.4-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Jul 24 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.4-4
- add requires beesu
- drop patch to remove open as root

* Wed Jul 24 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.4-3
- remove background patch as it breaks cinnamon next

* Mon Jul 22 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.4-2
- patch to fix create launcher

* Wed Jul 10 2013 leigh scott <leigh123linux@googlemail.com> - 1.8.4-1
- Update to version 1.8.4

* Thu Jun 06 2013 leigh scott <leigh123linux@googlemail.com> - 1.8.2-3
- autostart nemo differently so we dont squash nautilus

* Fri May 24 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.2-2
- Patch to remove open as root

* Mon May 20 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.2-1
- Update to version 1.8.2
- Tidy up patches

* Sun May 12 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.1-2
- add patch to stop nemo from drawing the desktop background

* Thu May 09 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.8.1-1
- update to 1.8.1 release

* Sun Feb 24 2013 Leigh Scott <leigh123linux@googlemail.com> - 1.1.2-4
- Rebuilt for libgnome-desktop soname bump
- Patch for gnome-desktop changes

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Fri Dec 21 2012 Kalev Lember <kalevlember@gmail.com> - 1.1.2-2
- Rebuilt for libgnome-desktop-3 3.7.3 soname bump

* Wed Nov 14 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.1.2-1
- update to 1.1.2 release
- add scriptlets for mimetype key

* Sat Nov 03 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.9-1
- update to 1.0.9 release

* Sun Oct 28 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.7-1
- update to 1.0.7 release
- change build requires style
- use autogen to prepare source
- make directory for extensions

* Sun Oct 21 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.5-2
- drop requires gksu-pokit

* Sat Oct 20 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.5-1
- update to 1.0.5 release
- revert last commit

* Thu Oct 18 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.3-3
- patch open as root and add requires gksu-pokit

* Mon Oct 08 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.3-2
- remove requires gnome-terminal
- patch to remove "open in terminal"

* Mon Oct 01 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.3-1
- update to 1.0.3 release

* Thu Sep 27 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.2-1
- update to 1.0.2 release
- add requires gnome-terminal

* Tue Sep 25 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.1-5
- add theme sub-package

* Tue Sep 25 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.1-4
- remove "open as root" option
- fix "open terminal" option

* Tue Sep 25 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.1-3
- validate desktop file

* Tue Sep 25 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.1-2
- add ldconfig to extensions
- fix comment in macro
- fix macro-in-comment
- remove obsolete provides/obsoletes
- fix licence tag

* Fri Sep 21 2012 Leigh Scott <leigh123linux@googlemail.com> - 1.0.1-1
- initial build based on nautilus spec file

